@@ -17,7 +17,7 @@ class MyView(Cocoa.NSView):
     currentMenuItem = objc.IBOutlet()
 
     def initWithFrame_(self, frameRect):
-        self = super(MyView, self).initWithFrame_(frameRect)
+        self = super().initWithFrame_(frameRect)
         if self is None:
             return None
 
